<?php

/**

 * Plugin Name: REST API Helper 
 * Plugin URI: http://ihsana.net/
 * Description: This plugin help REST API for display featured media source, author, categories, and custom fields. This plugin is made for Mobile Apps.  
 * Version: 1.8 
 * Author: JasmanXcrew 
 * Author URI: http://ihsana.net/

 * This plugin help REST API for display featured media source, author, categories, and custom fields. 
 * This plugin is made for IMA Builder, but it can work for others as well. 
 * 
 **/

# Exit if accessed directly
if (!defined("ABSPATH"))
{
    exit;
}

# Constant


/**
 * Exec Mode
 **/
define("IMH_EXEC", true);

/**
 * Enable Public Data Woo API
 **/
define("IMH_WOO", false);


/**
 * Plugin Base File
 **/
define("IMH_PATH", dirname(__file__));

/**
 * Plugin Base Directory
 **/
define("IMH_DIR", basename(IMH_PATH));

/**
 * Plugin Base URL
 **/
define("IMH_URL", plugins_url("/", __file__));

/**
 * Plugin Version
 **/
define("IMH_VERSION", "1.8");

/**
 * Debug Mode
 **/
define("IMH_DEBUG", true); //change false for distribution


/**
 * Base Class Plugin
 * @author JasmanXcrew
 *
 * @access public
 * @version 1.6
 * @package REST API Helper
 *
 **/

class IMHrestApiHelper
{
    var $append_galleries = true;
    var $post_types = array("page", "post");
    var $backlist_metatags = array(
        "_edit_lock",
        "_edit_last",
        "_wp_page_template",
        "_wp_old_slug",
        "post_password",
        "_wpb_vc_js_status",
        "_vc_post_settings");

    /**
     * Option Plugin
     * @access private
     **/
    private $options;

    /**
     * Instance of a class
     * @access public
     * @return void
     **/

    function __construct()
    {
        global $wp_post_types;

        $this->options = get_option("rest_api_helper_plugins"); // get current option
        add_action('init', array($this, 'imh_init'));
        add_action('rest_api_init', array($this, 'imh_rest_api_init'));
        add_action("plugins_loaded", array($this, "imh_textdomain")); //load language/textdomain
        add_action('shutdown', array($this, 'imh_post_type'));

        add_action('init', array($this, 'imh_handle_http_json'));

        $post_types = json_decode(get_option("imh_post_type"), true);
        if (!is_array($post_types))
        {
            $post_types = array("post", "page");
        }

        foreach ($post_types as $post_type)
        {
            if (!has_action("rest_prepare_$post_type"))
            {
                add_action("rest_prepare_$post_type", array($this, "imh_rest_prepare_post"), 10, 3);
            }
        }

        if (is_admin())
        {
            add_action("admin_menu", array($this, "imh_admin_menu_option_page")); // add option page
            add_action("admin_init", array($this, "imh_admin_menu_option_init"));
        }

        if (IMH_WOO == true)
        {
            add_action("rest_api_init", array($this, "imh_register_rest_route_woocommerce"));
        }

    }


    /**
     * IMHrestApiHelper::imh_register_rest_route_woocommerce()
     * 
     * @return void
     */
    function imh_register_rest_route_woocommerce()
    {

        register_rest_route("ima_wc/v2", "categories", array(
            "methods" => "GET",
            "callback" => array($this, "rest_route_categories_callback"),
            ));

        register_rest_route("ima_wc/v2", "products", array(
            "methods" => "GET",
            "callback" => array($this, "rest_route_products_callback"),
            "permission_callback" => function (WP_REST_Request $request)
            {
                return true; }
            ));

        register_rest_route("ima_wc/v2", 'products/(?P<id>[0-9]+)', array(
            "methods" => "GET",
            "callback" => array($this, "rest_route_product_callback"),
            "permission_callback" => function (WP_REST_Request $request)
            {
                return true; }
            ));


    }

    /**
     * IMHrestApiHelper::rest_route_categories_callback()
     * 
     * @return
     */
    function rest_route_categories_callback()
    {
        $new_term = array();
        $terms = get_terms('car_category');
        $z = 0;
        foreach ($terms as $term)
        {
            $new_term[$z]['id'] = $term->term_id;
            $new_term[$z]['name'] = $term->name;
            $new_term[$z]['slug'] = $term->slug;
            $new_term[$z]['count'] = $term->count;
            $new_term[$z]['description'] = $term->description;
            $new_term[$z]['permalink'] = esc_url(get_term_link($term));
            $thumbnail_id = get_woocommerce_term_meta($term->term_id, 'thumbnail_id', true);
            if ($thumbnail_id)
            {
                $image = wp_get_attachment_image_src($thumbnail_id, 'thumbnail');
                $image = $image[0];
            } else
            {
                $image = wc_placeholder_img_src();
            }
            $new_term[$z]['image']['src'] = $image;
            $new_term[$z]['_links']['self'] = get_option('siteurl') . '/wp-json/wp/v2/inventory/?car_category=' . $term->name . '';

            $z++;
        }
        return $new_term;
    }

    /**
     * IMHrestApiHelper::rest_route_product_callback()
     * 
     * @param mixed $request
     * @return
     */
    function rest_route_product_callback($request)
    {


        $product_id = intval(trim($request['id']));
        $product = get_post($product_id);


        $product_detail['id'] = $product->ID;
        $product_detail['name'] = $product->post_title;
        $product_detail['short_description'] = $product->post_excerpt;
        $product_detail['description'] = $product->post_content;
        $product_detail['permalink'] = $product->guid;
        $product_detail['average_rating'] = get_post_meta($product->ID, '_wc_average_rating', true);

        $product_detail['regular_price'] = get_post_meta($product->ID, '_regular_price', true);
        $product_detail['price'] = get_post_meta($product->ID, '_price', true);
        
        
        
        $currency_pos = get_option( 'woocommerce_currency_pos' );
        $format = '%1$s%2$s';
        
        switch ( $currency_pos ) {
        case 'left' :
        	$format = '%1$s%2$s';
        break;
        case 'right' :
        	$format = '%2$s%1$s';
        break;
        case 'left_space' :
        	$format = '%1$s&nbsp;%2$s';
        break;
        case 'right_space' :
        	$format = '%2$s&nbsp;%1$s';
        break;
        }

        $product_detail['price_html'] = wc_price(get_post_meta($product->ID, '_price', true)) ;
        
        $product_detail['sale_price'] = get_post_meta($product->ID, '_sale_price', true);
        $product_detail['sale_price_dates_from'] = get_post_meta($product->ID, '_sale_price_dates_from', true);
        $product_detail['sale_price_dates_to'] = get_post_meta($product->ID, '_sale_price_dates_to', true);
        $product_detail['virtual'] = get_post_meta($product->ID, '_virtual', true);
        $product_detail['tax_status'] = get_post_meta($product->ID, '_tax_status', true);
        $product_detail['tax_class'] = get_post_meta($product->ID, '_tax_class', true);
        $product_detail['visibility'] = get_post_meta($product->ID, '_visibility', true);
        $product_detail['purchase_note'] = get_post_meta($product->ID, '_purchase_note', true);

        $_product_image_gallery = get_post_meta($product->ID, '_product_image_gallery', true);

        $thumbnail_id = get_post_thumbnail_id($product->ID);
        $thumbnail = wp_get_attachment_image_src($thumbnail_id);
        $thumbnail_original = wp_get_attachment_image_src($thumbnail_id, 'original');
        $thumbnail_medium = wp_get_attachment_image_src($thumbnail_id, 'medium');
        $thumbnail_large = wp_get_attachment_image_src($thumbnail_id, 'large');

        $product_detail['featured']['thumbnail'] = $thumbnail[0];
        $product_detail['featured']['medium'] = $thumbnail_medium[0];
        $product_detail['featured']['large'] = $thumbnail_large[0];
        $product_detail['featured']['original'] = $thumbnail_original[0];

        $image_gallery = $image_slidebox = array();
        $galleries_ids = explode(",", $_product_image_gallery);
        foreach ($galleries_ids as $galleries_id)
        {
            if (is_numeric($galleries_id))
            {
                $image_gallery[] = wp_get_attachment_url($galleries_id);
                $image_slidebox[] = '<img src="' . wp_get_attachment_url($galleries_id) . '" />';
            }
        }

        $product_detail['image_gallery'] = $image_gallery;
        $product_detail['image_slidebox'] = implode('|', $image_slidebox);

        return $product_detail;
    }

    /**
     * IMHrestApiHelper::rest_route_products_callback()
     * 
     * @param mixed $request
     * @return
     */
    function rest_route_products_callback($request)
    {
        $parameters = $request->get_query_params();
        $new_products = array();

        if (isset($parameters["per_pages"]))
        {
            $numberposts = (int)$parameters["per_pages"];
        } else
        {
            $numberposts = -1;
        }

        $args = array(
            'post_type' => 'product',
            'posts_per_page' => $numberposts,
            'post_status' => 'publish',
            'meta_query' => array(array(
                    'key' => '_visibility',
                    'value' => array('catalog', 'visible'),
                    'compare' => 'IN')),

            );

        if (isset($parameters["categories"]))
        {
            $args['tax_query'] = array(array(
                    'taxonomy' => 'product_cat',
                    'field' => 'term_id',
                    'terms' => (int)$parameters["categories"],
                    'operator' => 'IN',
                    ));

        }

        $z = 0;
        $products = get_posts($args);
        if (is_array($products))
        {
            foreach ($products as $product)
            {
                $new_products[$z]['id'] = $product->ID;
                $new_products[$z]['name'] = $product->post_title;
                $new_products[$z]['short_description'] = $product->post_excerpt;
                $new_products[$z]['description'] = $product->post_content;
                $new_products[$z]['permalink'] = $product->guid;
                $new_products[$z]['average_rating'] = get_post_meta($product->ID, '_wc_average_rating', true);


                $new_products[$z]['regular_price'] = get_post_meta($product->ID, '_regular_price', true);
                $new_products[$z]['price'] = get_post_meta($product->ID, '_price', true);
                $new_products[$z]['price_html'] = wc_price(get_post_meta($product->ID, '_price', true)) ;
                
                $new_products[$z]['sale_price'] = get_post_meta($product->ID, '_sale_price', true);
                $new_products[$z]['sale_price_dates_from'] = get_post_meta($product->ID, '_sale_price_dates_from', true);
                $new_products[$z]['sale_price_dates_to'] = get_post_meta($product->ID, '_sale_price_dates_to', true);
                $new_products[$z]['total_sales'] = get_post_meta($product->ID, 'total_sales', true);
                $new_products[$z]['virtual'] = get_post_meta($product->ID, '_virtual', true);
                $new_products[$z]['tax_status'] = get_post_meta($product->ID, '_tax_status', true);
                $new_products[$z]['tax_class'] = get_post_meta($product->ID, '_tax_class', true);
                $new_products[$z]['visibility'] = get_post_meta($product->ID, '_visibility', true);
                $new_products[$z]['purchase_note'] = get_post_meta($product->ID, '_purchase_note', true);


                $_product_image_gallery = get_post_meta($product->ID, '_product_image_gallery', true);

                $thumbnail_id = get_post_thumbnail_id($product->ID);
                $thumbnail = wp_get_attachment_image_src($thumbnail_id);
                $thumbnail_original = wp_get_attachment_image_src($thumbnail_id, 'original');
                $thumbnail_medium = wp_get_attachment_image_src($thumbnail_id, 'medium');
                $thumbnail_large = wp_get_attachment_image_src($thumbnail_id, 'large');

                $new_products[$z]['featured']['thumbnail'] = $thumbnail[0];
                $new_products[$z]['featured']['medium'] = $thumbnail_medium[0];
                $new_products[$z]['featured']['large'] = $thumbnail_large[0];
                $new_products[$z]['featured']['original'] = $thumbnail_original[0];

                $image_gallery = array();
                $galleries_ids = explode(",", $_product_image_gallery);
                foreach ($galleries_ids as $galleries_id)
                {
                    if (is_numeric($galleries_id))
                    {
                        $image_gallery[] = wp_get_attachment_url($galleries_id);
                    }
                }

                $new_products[$z]['image_gallery'] = $image_gallery;
                //$new_products[$z]['_links']['self'] = get_option('siteurl') . '/wp-json/ima_wc/v2/products/' . $product->ID;


                $z++;
            }
        }


        return $new_products;
    }

    /**
     * IMHrestApiHelper::imh_init()
     * 
     * @return void
     */
    function imh_init()
    {
        if (isset($this->options['custom_field_blacklist']))
        {
            $metatags = explode(",", $this->options['custom_field_blacklist']);
            if (is_array($metatags))
            {
                foreach ($metatags as $metatag)
                {
                    $this->backlist_metatags[] = ltrim(rtrim($metatag));
                }
            }
        }
    }

    /**
     * IMHrestApiHelper::imh_rest_api_init()
     * 
     * @return void
     */
    function imh_rest_api_init()
    {

        register_rest_field('page', 'content', array(
            'get_callback' => array($this, 'imh_do_shortcodes'),
            'update_callback' => null,
            'schema' => null,
            ));

        register_rest_field('post', 'content', array(
            'get_callback' => array($this, 'imh_do_shortcodes'),
            'update_callback' => null,
            'schema' => null,
            ));
    }


    function imh_do_shortcodes($object, $field_name, $request)
    {
        global $post;

        // visual composer
        if (class_exists('WPBMap'))
        {
            WPBMap::addAllMappedShortcodes();
        }

        $post = get_post($object['id']);
        $output['rendered'] = apply_filters('the_content', $post->post_content);
        return $output;
    }


    /**
     * Add option page.
     * @link http://codex.wordpress.org/Function_Reference/add_options_page
     * @access public
     * @return void
     **/
    public function imh_admin_menu_option_page()
    {
        add_options_page(__("REST API Helper Option", "rest-api-helper"), //page title
            __("REST API Helper Option", "rest-api-helper"), //menu title
            "manage_options", //capability
            "imh_settings", //slug
            array($this, "imh_admin_menu_option_page_markup"));
    }


    /**
     * Create option page markup
     *
     * @access public
     * @return void
     **/
    public function imh_admin_menu_option_page_markup()
    {
        $this->options = get_option("rest_api_helper_plugins");
        _e("<div class='wrap'>");
        _e("<h1>" . __("REST API Helper", "rest-api-helper") . "</h1>");
        _e("<div class='postbox'>");
        _e("<div class='inside'>");
        _e("<form method='post' action='options.php'>");
        // This prints out all hidden setting fields
        settings_fields("imh_option_group");
        do_settings_sections("imh-settings");
        submit_button();
        _e("</form>");
        _e('<p>If you still have problems with CORS preflight channel, you can add this code to .htaccess</p>');
        _e('<pre>Header set Access-Control-Allow-Headers "Content-Type, Authorization"</pre>');
        _e("</div>");
        _e("</div>");
        _e("</div>");
    }


    /**
     * option instance
     * @link https://codex.wordpress.org/Function_Reference/register_setting
     * @access public
     * @return void
     **/
    public function imh_admin_menu_option_init()
    {

        #info: https://codex.wordpress.org/Function_Reference/register_setting
        register_setting("imh_option_group", // group
            "rest_api_helper_plugins", //name
            array($this, "imh_admin_menu_option_sanitize") //sanitize_callback
            );

        #info: https://codex.wordpress.org/Function_Reference/add_settings_section
        add_settings_section("imh_section_id", //id
            __("Settings", "rest-api-helper"), //title
            array($this, "imh_admin_menu_option_section_info"), //callback
            "imh-settings" //page
            );


        #info: https://codex.wordpress.org/Function_Reference/add_settings_field
        add_settings_field("custom_field_blacklist", //id
            __("Custom Field Blacklist", "rest-api-helper"), //title
            array($this, "imh_admin_menu_option_custom_field_blacklist_callback"), //callback
            "imh-settings", //page
            "imh_section_id" //section
            );

        #info: https://codex.wordpress.org/Function_Reference/add_settings_field
        add_settings_field("json_mode", //id
            __("JSON Mode", "rest-api-helper"), //title
            array($this, "imh_admin_menu_option_json_mode_callback"), //callback
            "imh-settings", //page
            "imh_section_id" //section
            );

    }


    /**
     * Sanitize Callback 
     * A callback function that sanitizes the option's value
     * 
     * @param mixed $input
     * @see imh_admin_menu_option_init()
     **/
    public function imh_admin_menu_option_sanitize($input)
    {
        $new_input = array();
        if (isset($input["auth_basic_for"]))
            $new_input["auth_basic_for"] = sanitize_text_field($input["auth_basic_for"]);

        if (isset($input["custom_field_blacklist"]))
            $new_input["custom_field_blacklist"] = sanitize_text_field($input["custom_field_blacklist"]);

        if (isset($input["json_mode"]))
            $new_input["json_mode"] = sanitize_text_field($input["json_mode"]);

        return $new_input;
    }


    /**
     * Option page callback (auth_basic_for)
     * 
     * @return void
     * @see imh_admin_menu_option_init()
     **/
    public function imh_admin_menu_option_auth_basic_for_callback()
    {
        if (isset($this->options["auth_basic_for"]))
        {
            $current_imh_option_auth_basic_for = esc_attr($this->options["auth_basic_for"]);
        } else
        {
            $current_imh_option_auth_basic_for = "";
        }


        /**
         * Create HTML Drowndown Users Using API
         * @see https://codex.wordpress.org/Function_Reference/wp_dropdown_users
         */

        $args = array(
            "echo" => 0,
            "name" => "rest_api_helper_plugins[auth_basic_for]",
            "id" => "imh_option_auth_basic_for", // string
            "class" => "imh imh-form-control reguler-text", // string
            "selected" => $current_imh_option_auth_basic_for // string
                );
        $dropdown_users = wp_dropdown_users($args);
        $description = __("Please select a user", "imh-textdomain");
        printf("%s<p class='description'>%s</p>", $dropdown_users, $description);
    }


    /**
     * Option page callback (custom_field_blacklist)
     * 
     * @return void
     * @see imh_admin_menu_option_init()
     **/
    public function imh_admin_menu_option_custom_field_blacklist_callback()
    {
        if (isset($this->options["custom_field_blacklist"]))
        {
            $current_imh_option_custom_field_blacklist = esc_attr($this->options["custom_field_blacklist"]);
        } else
        {
            $current_imh_option_custom_field_blacklist = "";
        }
        $description = __("separator with coma", "rest-api-helper");
        printf("<textarea class='imh imh-form-control large-text' id='imh_option_custom_field_blacklist' name='rest_api_helper_plugins[custom_field_blacklist]' >%s</textarea><p class='description'>%s</p>", $current_imh_option_custom_field_blacklist, $description);
    }


    /**
     * Option page callback (json_mode)
     * 
     * @return void
     * @see imh_admin_menu_option_init()
     **/
    public function imh_admin_menu_option_json_mode_callback()
    {
        if (isset($this->options["json_mode"]))
        {
            $current_imh_option_json_mode = esc_attr($this->options["json_mode"]);
        } else
        {
            $current_imh_option_json_mode = "restapi2";
        }
        $input = null;
        $input_options = array();
        $input_options[] = array("value" => "restapi2", "label" => __("WP REST-API", "rest-api-helper"));
        //$input_options[] = array("value" => "json_encode", "label" => __("PHP JSON Encode", "rest-api-helper"));
        $input .= "<select class='imh-form-control reguler-text' id='imh_option_json_mode' name='rest_api_helper_plugins[json_mode]' >";
        foreach ($input_options as $input_option)
        {
            $selected = "";
            if ($input_option["value"] == $current_imh_option_json_mode)
            {
                $selected = "selected";
            }
            $input .= "<option value='" . $input_option["value"] . "' " . $selected . ">" . $input_option["label"] . "</option>";
        }
        $input .= "</select>";
        printf($input);
    }


    /**
     * Display page option section
     * @access public
     * @return void
     **/
    public function imh_admin_menu_option_section_info()
    {
        _e("Enter your settings below:", "rest-api-helper");
    }


    /**
     * IMHrestApiHelper::imh_post_type()
     * 
     * @return void
     */
    public function imh_post_type()
    {
        $new_value = array();
        foreach (get_post_types(array('show_ui' => true), 'names') as $post_type)
        {
            $new_value[] = $post_type;
        }
        update_option("imh_post_type", json_encode($new_value), true);
    }

    /**
     * IMHrestApiHelper::imh_rest_prepare_post()
     * 
     * @param mixed $data
     * @param mixed $term
     * @param mixed $context
     * @return
     */
    public function imh_rest_prepare_post($data, $term, $context)
    {
        $_data = $data->data;

        $thumbnail_id = get_post_thumbnail_id($_data["id"]);
        $thumbnail = wp_get_attachment_image_src($thumbnail_id);
        $thumbnail_original = wp_get_attachment_image_src($thumbnail_id, 'original');
        $thumbnail_medium = wp_get_attachment_image_src($thumbnail_id, 'medium');
        $thumbnail_large = wp_get_attachment_image_src($thumbnail_id, 'large');

        if (isset($_data['categories']))
        {
            $ionic_categories = array();
            foreach ($_data['categories'] as $cat_id)
            {
                $terms = get_term($cat_id);
                $ionic_categories[] = $terms->name;
            }
            $_data['x_categories'] = implode(", ", $ionic_categories);
        }

        if (isset($_data['car_category']))
        {
            $ionic_categories = array();
            foreach ($_data['car_category'] as $cat_id)
            {
                $terms = get_term($cat_id);
                $ionic_categories[] = $terms->name;
            }
           // $_data['x_car_category'] = implode(", ", $ionic_categories);
        }

        if (isset($_data['tags']))
        {
            $ionic_tags = array();
            foreach ($_data['tags'] as $tags_id)
            {
                $terms = get_term($tags_id);
                $ionic_tags[] = $terms->name;
            }
            $_data['x_tags'] = implode(", ", $ionic_tags);
        }

        // get all meta
        global $wpdb;
        $table = _get_meta_table('post');
        if (!$table)
        {
            return false;
        }

        $metakeys = $wpdb->get_results($wpdb->prepare("SELECT meta_key FROM `$table` WHERE `post_id`=%d", $_data["id"]));

        //$_data['x_featured_media'] = $thumbnail[0];
        //$_data['x_featured_media_medium'] = $thumbnail_medium[0];
        //$_data['x_featured_media_large'] = $thumbnail_large[0];
        //$_data['x_featured_media_original'] = $thumbnail_original[0];
        //$_data['x_date'] = get_the_date(get_option('date_format'), $_data["id"]);
        //$_data['x_author'] = get_the_author($_data["author"]);
		unset( $_data['author'] );
		unset( $_data['date'] );
		unset( $_data['date_gmt'] );
		unset( $_data['guid'] );
		unset( $_data['modified'] );
		unset( $_data['modified_gmt'] );
		unset( $_data['status'] );
		unset( $_data['type'] );
		unset( $_data['link'] );
		unset( $_data['content'] );
		unset( $_data['excerpt'] );
		unset( $_data['featured_media'] );
		unset( $_data['comment_status'] );
		unset( $_data['ping_status'] );
		unset( $_data['template'] );
		unset( $_data['meta'] );
        //$_data['x_content'] = do_shortcode($_data["content"]["rendered"]);
        foreach ($metakeys as $key)
        {
            if (!in_array($key->meta_key, $this->backlist_metatags))
            {
                $_data['x_metadata'][$key->meta_key] = get_post_meta($_data["id"], $key->meta_key, true);
				unset( $_data['x_metadata']['certified'] );
				unset( $_data['x_metadata']['company_address'] );
				unset( $_data['x_metadata']['company_city'] );
				unset( $_data['x_metadata']['company_name'] );
				unset( $_data['x_metadata']['company_phone'] );
				unset( $_data['x_metadata']['company_state'] );
				unset( $_data['x_metadata']['company_zip'] );
				unset( $_data['x_metadata']['doors'] );
				//unset( $_data['x_metadata']['engine'] );
				unset( $_data['x_metadata']['fuel'] );
				//unset( $_data['x_metadata']['int_color'] );
				unset( $_data['x_metadata']['listing_id'] );
				unset( $_data['x_metadata']['options'] );
            }
        }
        $_data_img = array();
        // woo helper
        if (get_post_meta($_data["id"], "_product_image_gallery", true))
        {
            $image_galleries = explode(",", get_post_meta($_data["id"], "_product_image_gallery", true));
            if (is_array($image_galleries))
            {
                foreach ($image_galleries as $image_gallery)
                {
                    $image_galleries = wp_get_attachment_image_src((int)$image_gallery, 'original');
                    if (isset($image_galleries[0]))
                    {
                        $_data['x_product_image_gallery'][] = $image_galleries[0];
                        $_data_img[] = '<img src="' . $image_galleries[0] . '" />';
                    }
                }
            }
            if (count($_data_img) > 0)
            {
                $_data['x_slidebox'] = implode('|', $_data_img);
            }

        }


        $data->data = $_data;
        return $data;
    }

    /**
     * IMHrestApiHelper::imh_handle_http_json()
     * 
     * @return void
     */
    function imh_handle_http_json()
    {

        if (preg_match("/json|api/", $_SERVER["REQUEST_URI"]))
        {
            if (isset($_SERVER['HTTP_ORIGIN']))
            {
                header("Access-Control-Allow-Origin: {$_SERVER['HTTP_ORIGIN']}");
                header('Access-Control-Allow-Credentials: true');
                header('Access-Control-Max-Age: 86400'); // cache for 1 day
// How long my cache should last
$cacheDuration=7200; // in seconds
// Client is told to cache these results for set duration
header('Cache-Control: public,max-age='.$cacheDuration.',must-revalidate');
header('Expires: '.gmdate('D, d M Y H:i:s',($_SERVER['REQUEST_TIME']+$cacheDuration)).' GMT');
header('Last-modified: '.gmdate('D, d M Y H:i:s',$_SERVER['REQUEST_TIME']).' GMT');

// Pragma header removed should the server happen to set it automatically
// Pragma headers can make browser misbehave and still ask data from server
header_remove('Pragma');
            }

            if ($_SERVER['REQUEST_METHOD'] == 'OPTIONS')
            {
                if (isset($_SERVER['HTTP_ACCESS_CONTROL_REQUEST_METHOD']))
                    header("Access-Control-Allow-Methods: GET, POST, PUT, DELETE, OPTIONS");

                if (isset($_SERVER['HTTP_ACCESS_CONTROL_REQUEST_HEADERS']))
                    header("Access-Control-Allow-Headers: {$_SERVER['HTTP_ACCESS_CONTROL_REQUEST_HEADERS']}");
            }

            header("X-Powered-By: Ionic Mobile App Builder");

        }
    }


    /**
     * Loads the plugin's translated strings
     * @link http://codex.wordpress.org/Function_Reference/load_plugin_textdomain
     * @access public
     * @return void
     **/
    public function imh_textdomain()
    {
        load_plugin_textdomain("rest-api-helper", false, IMH_DIR . "/languages");
    }

}


new IMHrestApiHelper();
